@@ -114,7 +114,7 @@ def c_main(stdscr: 'curses._CursesWindow'):
         elif key == ord('d'): # MARK AS DONE/UNDONE
             done(selected_task)
         elif key == ord('r'): # REMOVE TASK
-            if selected_task != None:
+            if selected_task:
                 del tasks[task_index]
                 task_index -= 1
         elif key == ord('w'): # WRITE CHANGE TO FILE
@@ -134,4 +134,4 @@ def main():
     return curses.wrapper(c_main)
 
 if __name__ == '__main__':
-    exit(main()) 
+    exit(main()) 
\ No newline at end of file
